@@ -7,14 +7,17 @@ package Lemonldap::NG::Common::CGI;
 
 use strict;
 
+use File::Basename;
 use MIME::Base64;
 use Time::Local;
 use CGI;
 use utf8;
+use Encode;
+use Net::CIDR::Lite;
 
 #parameter syslog Indicates syslog facility for logging user actions
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.2.3';
 
 use base qw(CGI);
 
@@ -46,6 +49,7 @@ sub new {
         $self->{_prm}->{$_} = $self->param($_);
         $self->delete($_);
     }
+    $self->{lang} = extract_lang();
     bless $self, $class;
     return $self;
 }
@@ -130,6 +134,13 @@ sub setApacheUser {
     $ENV{REMOTE_USER} = $user;
 }
 
+##@method string getApacheHtdocsPath()
+# Return absolute path to the htdocs directory where the current script is
+# @return path string
+sub getApacheHtdocsPath {
+    return dirname( $ENV{SCRIPT_FILENAME} || $0 );
+}
+
 ## @method void soapTest(string soapFunctions, object obj)
 # Check if request is a SOAP request. If it is, launch
 # Lemonldap::NG::Common::CGI::SOAPServer and exit. Else simply return.
@@ -286,7 +297,7 @@ sub userLog {
 # @param $mess string to log
 sub userInfo {
     my ( $self, $mess ) = @_;
-    $mess = "Lemonldap::NG : $mess ($ENV{REMOTE_ADDR})";
+    $mess = "Lemonldap::NG : $mess (" . $self->ipAddr . ")";
     $self->userLog( $mess, 'info' );
 }
 
@@ -296,7 +307,7 @@ sub userInfo {
 # @param $mess string to log
 sub userNotice {
     my ( $self, $mess ) = @_;
-    $mess = "Lemonldap::NG : $mess ($ENV{REMOTE_ADDR})";
+    $mess = "Lemonldap::NG : $mess (" . $self->ipAddr . ")";
     $self->userLog( $mess, 'notice' );
 }
 
@@ -306,7 +317,7 @@ sub userNotice {
 # @param $mess string to log
 sub userError {
     my ( $self, $mess ) = @_;
-    $mess = "Lemonldap::NG : $mess ($ENV{REMOTE_ADDR})";
+    $mess = "Lemonldap::NG : $mess (" . $self->ipAddr . ")";
     $self->userLog( $mess, 'warn' );
 }
 
@@ -326,6 +337,32 @@ sub _sub {
     }
 }
 
+##@method string extract_lang
+#@return array of user's preferred languages (two letters)
+sub extract_lang {
+    my $self = shift;
+
+    my @langs = split /,\s*/, ( shift || $ENV{HTTP_ACCEPT_LANGUAGE} || "" );
+    my @res = ();
+
+    foreach (@langs) {
+
+        # Languages are supposed to be sorted by preference
+        my $lang = ( split /;/ )[0];
+
+        # Take first part of lang code (part before -)
+        $lang = ( split /-/, $lang )[0];
+
+        # Go to next if lang was already added
+        next if grep( /$lang/, @res );
+
+        # Store lang only if size is 2 characters
+        push @res, $lang if ( length($lang) == 2 );
+    }
+
+    return \@res;
+}
+
 ##@method void translate_template(string text_ref, string lang)
 # translate_template is used as an HTML::Template filter to tranlate strings in
 # the wanted language
@@ -335,12 +372,6 @@ sub _sub {
 sub translate_template {
     my $self     = shift;
     my $text_ref = shift;
-    my $lang     = shift || $ENV{HTTP_ACCEPT_LANGUAGE};
-
-    # Get the lang code (2 letters)
-    $lang = lc($lang);
-    $lang =~ s/-/_/g;
-    $lang =~ s/^(..).*$/$1/;
 
     # Decode UTF-8
     utf8::decode($$text_ref);
@@ -348,12 +379,26 @@ sub translate_template {
     # Test if a translation is available for the selected language
     # If not available, return the first translated string
     # <lang en="Please enter your credentials" fr="Merci de vous autentifier"/>
-    if ( $$text_ref =~ m/$lang=\"(.*?)\"/ ) {
-        $$text_ref =~ s/<lang.*$lang=\"(.*?)\".*?\/>/$1/gx;
-    }
-    else {
-        $$text_ref =~ s/<lang\s+\w+=\"(.*?)\".*?\/>/$1/gx;
+    foreach ( @{ $self->{lang} } ) {
+        if ( $$text_ref =~ m/$_=\"(.*?)\"/ ) {
+            $$text_ref =~ s/<lang.*$_=\"(.*?)\".*?\/>/$1/gx;
+            return;
+        }
     }
+    $$text_ref =~ s/<lang\s+\w+=\"(.*?)\".*?\/>/$1/gx;
+}
+
+##@method void session_template(string text_ref)
+# session_template is used as an HTML::Template filter to replace session info
+# by their value
+#@param text_ref reference to the string to translate
+#@return
+sub session_template {
+    my $self     = shift;
+    my $text_ref = shift;
+
+    # Replace session information
+    $$text_ref =~ s/\$(\w+)/decode("utf8",$self->{sessionInfo}->{$1})/ge;
 }
 
 ## @method private void quit()
@@ -362,6 +407,43 @@ sub quit {
     exit;
 }
 
+##@method string ipAddr()
+# Retrieve client IP address from remote address or X-FORWARDED-FOR header
+#@return client IP
+sub ipAddr {
+    my $self = shift;
+
+    unless ( $self->{ipAddr} ) {
+        $self->{ipAddr} = $ENV{REMOTE_ADDR};
+        if ( my $xheader = $ENV{HTTP_X_FORWARDED_FOR} ) {
+            if (   $self->{trustedProxies} =~ /\*/
+                or $self->{useXForwardedForIP} )
+            {
+                $self->{ipAddr} = $1 if ( $xheader =~ /^([^,]*)/ );
+            }
+            elsif ( $self->{trustedProxies} ) {
+                my $localIP =
+                  Net::CIDR::Lite->new("127.0.0.0/8"); # TODO: add IPv6 local IP
+                my $trustedIP =
+                  Net::CIDR::Lite->new( split /\s+/, $self->{trustedProxies} );
+                while (
+                    (
+                           $localIP->find( $self->{ipAddr} )
+                        or $trustedIP->find( $self->{ipAddr} )
+                    )
+                    and $xheader =~ s/[,\s]*([^,\s]+)$//
+                  )
+                {
+
+                    # because it is of no use to store a local IP as client IP
+                    $self->{ipAddr} = $1 unless ( $localIP->find($1) );
+                }
+            }
+        }
+    }
+    return $self->{ipAddr};
+}
+
 1;
 
 __END__
@@ -403,14 +485,49 @@ L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=back
+
+=head1 BUG REPORT
+
+Use OW2 system to report bug or ask for features:
+L<http://jira.ow2.org>
+
+=head1 DOWNLOAD
+
+Lemonldap::NG is available at
+L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006, 2007, 2010 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Copyright (C) 2008, 2009, 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2012, 2013 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Copyright (C) 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
