@@ -10,13 +10,14 @@ use strict;
 use Lemonldap::NG::Handler::SharedConf qw(:all);
 use Digest::MD5 qw(md5_base64);
 use MIME::Base64;
+use HTTP::Headers;
 use SOAP::Lite;    # link protected portalRequest
 
 use base qw(Lemonldap::NG::Handler::SharedConf);
 use utf8;
 no utf8;
 
-our $VERSION = '1.2.2';
+our $VERSION = '1.2.3';
 
 # We need just this constant, that's why Portal is 'required' but not 'used'
 *PE_OK = *Lemonldap::NG::Portal::SharedConf::PE_OK;
@@ -65,14 +66,23 @@ sub run ($$) {
     # II - recover the user datas
     #  2.1 search if the user was the same as previous (very efficient in
     #      persistent connection).
-    unless ( $id eq $datas->{_session_id} ) {
+    unless ( $id eq $datas->{_cache_id} ) {
 
         # 2.2 search in the local cache if exists
         unless ( $refLocalStorage and $datas = $refLocalStorage->get($id) ) {
 
             # 2.3 Authentication by Lemonldap::NG::Portal using SOAP request
+
+            # Add client IP as X-Forwarded-For IP in SOAP request
+            my $xheader = lmHeaderIn( $apacheRequest, 'X-Forwarded-For' );
+            $xheader .= ", " if ($xheader);
+            $xheader .= $apacheRequest->connection->remote_ip;
+            my $soapHeaders =
+              HTTP::Headers->new( "X-Forwarded-For" => $xheader );
+
             my $soap =
-              SOAP::Lite->proxy( $class->portal() )
+              SOAP::Lite->proxy( $class->portal(),
+                default_headers => $soapHeaders )
               ->uri('urn:Lemonldap::NG::Common::CGI::SOAPService');
             $user = decode_base64($user);
             ( $user, $pass ) = ( $user =~ /^(.*?):(.*)$/ );
@@ -116,6 +126,7 @@ sub run ($$) {
                 return $class->goToPortal($uri);
             }
             $datas->{$_} = $h{$_} foreach ( keys %h );
+            $datas->{_cache_id} = $id;
 
             # Store now the user in the local storage
             if ($refLocalStorage) {
@@ -134,16 +145,16 @@ sub run ($$) {
     $class->updateStatus( $datas->{$whatToTrace}, $apacheRequest->uri, 'OK' );
     $class->logGranted( $uri, $datas );
 
-    # ACCOUNTING
-    # 2 - Inform remote application
-    $class->sendHeaders;
-
     # SECURITY
     # Hide Lemonldap::NG cookie
     $class->hideCookie;
 
     # Hide user password
-    $class->lmSetHeaderIn( $apacheRequest, Authorization => '' );
+    $class->lmUnsetHeaderIn( $apacheRequest, "Authorization" );
+
+    # ACCOUNTING
+    # 2 - Inform remote application
+    $class->sendHeaders;
     OK;
 }
 
@@ -201,7 +212,15 @@ L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=back
 
 =head1 BUG REPORT
 
@@ -215,10 +234,27 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008, 2010 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Copyright (C) 2008, 2009, 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2012, 2013 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Copyright (C) 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
