@@ -134,7 +134,7 @@ sub run($$) {
 # Test if configuration has changed and launch setConf() if needed.
 # If the optional boolean $local is true, remote configuration is not tested:
 # only local cached configuration is tested if available. $local is given to
-# Lemonldap::NG::Conf::getConf()
+# Lemonldap::NG::Common::getConf()
 # @param $local boolean
 # @return Apache constant
 sub testConf {
@@ -233,7 +233,7 @@ configuration provide by Lemonldap::NG::Manager.
   __PACKAGE__->init ( {
     localStorage        => "Cache::FileCache",
     localStorageOptions => {
-        'namespace' => 'MyNamespace',
+        'namespace' => 'lemonldap-ng',
         'default_expires_in' => 600,
       },
     configStorage       => {
@@ -306,7 +306,15 @@ L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=back
 
 =head1 BUG REPORT
 
@@ -320,10 +328,27 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005, 2007, 2010 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Copyright (C) 2006, 2007, 2008, 2009, 2010, 2013 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2012 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Copyright (C) 2006, 2008, 2009, 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
