@@ -9,7 +9,7 @@ package Lemonldap::NG::Manager::_i18n;
 
 use strict;
 use AutoLoader qw(AUTOLOAD);
-our $VERSION = '1.1.2';
+our $VERSION = '1.2.3';
 
 ## @method string translate(string text,string lang)
 # Returns $text translated in $lang.
@@ -112,6 +112,7 @@ sub en {
         casStorage             => 'CAS sessions module name',
         casStorageOptions      => 'CAS sessions module options',
         cda                    => 'Multiple domains',
+        checkXSS               => 'Check XSS attacks',
         clickHereToForce       => 'Click here to force',
         choiceParams           => 'Choice parameters',
         Configuration          => 'Configuration',
@@ -131,10 +132,11 @@ sub en {
         error                           => 'Error',
         exportedAttr                    => 'SOAP exported attributes',
         exportedVars                    => 'Exported Variables',
+        failedLoginNumber               => 'Number of registered failed logins',
         generalParameters               => 'General Parameters',
         globalStorage                   => 'Apache::Session module',
         globalStorageOptions            => 'Apache::Session module parameters',
-        grantSessionRule                => 'Opening conditions',
+        grantSessionRules               => 'Opening conditions',
         groups                          => 'Groups',
         headers                         => 'HTTP Headers',
         hideOldPassword                 => 'Hide old password',
@@ -157,6 +159,7 @@ sub en {
         issuerDBOpenIDPath              => 'Path',
         issuerDBOpenIDRule              => 'Use rule',
         issuerDBOpenIDOptions           => 'Options',
+        jsRedirect                      => 'Redirection message',
         key                             => 'Encryption key',
         ldap                            => 'LDAP',
         ldapAuthnLevel                  => 'Authentication level',
@@ -186,6 +189,8 @@ sub en {
         ldapTimeout                     => 'Timeout',
         ldapUsePasswordResetAttribute   => 'Use reset attribute',
         ldapVersion                     => 'Version',
+        loginHistory                    => 'Login history',
+        loginHistoryEnabled             => 'Activation',
         logoutServices                  => 'Logout forward',
         logParams                       => 'Logs',
         macros                          => 'Macros',
@@ -197,12 +202,14 @@ sub en {
         mailFrom                        => 'Mail sender',
         mailHeaders                     => 'Mail headers',
         mailLDAPFilter                  => 'Mail filter',
-        mailOther                       => 'Other',
-        mailReplyTo                     => 'Reply address',
+        mailOnPasswordChange   => 'Send a mail when password is changed',
+        mailOther              => 'Other',
+        mailReplyTo            => 'Reply address',
         mailSessionKey         => 'Session key containing mail address',
         mailSubject            => 'Success mail subject',
         mailTimeout            => 'Validity time of a password reset request',
         mailUrl                => 'Page URL',
+        maintenance            => 'Maintenance mode',
         managerDn              => 'Account',
         managerPassword        => 'Password',
         memberOfSSOGroups      => 'Member of SSO groups',
@@ -253,9 +260,11 @@ sub en {
         portal                      => 'URL',
         portalAntiFrame             => 'Anti frame protection',
         portalAutocomplete          => 'Auto complete',
+        portalCheckLogins           => 'Check last logins',
         portalCustomization         => 'Customization',
         portalDisplayAppslist       => 'Applications list',
         portalDisplayChangePassword => 'Password change',
+        portalDisplayLoginHistory   => 'Login History',
         portalDisplayLogout         => 'Logout',
         portalDisplayResetPassword  => 'Reset password',
         portalForceAuthn            => 'Force authentication',
@@ -263,14 +272,21 @@ sub en {
         portalModules               => 'Modules activation',
         portalOpenLinkInNewWindow   => 'New window',
         portalParams                => 'Portal',
+        portalRedirection           => 'Portal redirections',
         portalRequireOldPassword    => 'Require old password',
-        portalSkin                  => 'Skin',
+        portalSkin                  => 'Default Skin',
+        portalSkinRules             => 'Skin display rules',
         portalUserAttr              => 'User attribute',
         post                        => 'Form replay',
         proxyParams                 => 'Proxy parameters',
         purgeNotification           => 'Delete notification definitely',
+        radiusAuthnLevel            => 'Authentication level',
+        radiusParams                => 'Radius parameters',
+        radiusSecret                => 'Shared secret',
+        radiusServer                => 'Server hostname',
         randomPasswordRegexp        => 'Regexp for password generation',
         redirection                 => 'Handler redirections',
+        reloadUrls                  => 'Configuration reload',
         remoteCookieName            => 'Cookie name',
         remoteGlobalStorage         => 'Sessions module',
         remoteGlobalStorageOptions  => 'Sessions module options',
@@ -288,6 +304,7 @@ sub en {
         security                    => 'Security',
         session                     => 'session',
         sessions                    => 'sessions',
+        sessionDataToRemember       => 'Session data to store',
         sessionDeleted              => 'The session was deleted',
         sessionParams               => 'Sessions',
         sessionStartedAt            => 'Session started on',
@@ -297,6 +314,7 @@ sub en {
         singleSession               => 'One session only by user',
         singleUserByIP              => 'One user by IP address',
         slaveAuthnLevel             => 'Authentication level',
+        slaveMasterIP               => 'Master\'s IP address',
         slaveParams                 => 'Slave parameters',
         slaveUserHeader             => "Header for user login",
         SMTPAuthPass                => 'SMTP password',
@@ -308,12 +326,11 @@ sub en {
         soapSessionService          => 'SOAP sessions end point',
         specialHandlers             => 'Special Handlers',
         SSLAuthnLevel               => 'Authentication level',
-        SSLLDAPField                => 'LDAP attribute used in filter',
         sslParams                   => 'SSL parameters',
-        SSLRequire                  => 'SSL Required',
         SSLVar                      => 'Extracted certificate field',
         startTime                   => 'Creation date',
         storePassword               => 'Store user password in session datas',
+        successLoginNumber          => 'Number of registered logins',
         sympaHandler                => 'Sympa',
         sympaMailKey                => 'Mail session key',
         sympaSecret                 => 'Shared secret',
@@ -322,6 +339,7 @@ sub en {
         timeout                     => 'Sessions timeout',
         timeoutActivity             => 'Sessions activity timeout',
         trustedDomains              => 'Trusted domains',
+        trustedProxies              => 'Trusted proxies IP',
         twitterAppName              => 'Application name',
         twitterAuthnLevel           => 'Authentication level',
         twitterKey                  => 'API key',
@@ -338,15 +356,14 @@ sub en {
         useRedirectOnError          => 'Redirect on error',
         useRedirectOnForbidden      => 'Redirect on forbidden',
         useSafeJail                 => 'Use Safe jail',
-        useXForwardedForIP          => "Use X-Forwarded-For",
         variables                   => "Variables",
         vhostHttps                  => 'HTTPS',
+        vhostMaintenance            => 'Maintenance mode',
         vhostOptions                => 'Options',
         vhostPort                   => 'Port',
         virtualHosts                => 'Virtual Hosts',
         warning                     => 'Warning',
         whatToTrace                 => "REMOTE_USER",
-        xForwardedForAddr           => 'Forwarded IP address',
         yubikeyAuthnLevel           => 'Authentication level',
         yubikeyClientID             => 'API client ID',
         yubikeyParams               => 'Yubikey parameters',
@@ -545,6 +562,7 @@ sub fr {
         casStorage             => 'Nom du module des session CAS',
         casStorageOptions      => 'Options du module des sessions CAS',
         cda                    => 'Domaines multiples',
+        checkXSS               => 'Contrôler les attaques XSS',
         clickHereToForce       => 'Cliquer ici pour forcer',
         choiceParams           => 'Paramètres des choix',
         Configuration          => 'Configuration',
@@ -564,51 +582,53 @@ sub fr {
         error          => 'Erreur',
         exportedAttr   => 'Attributs exportés par le portail (SOAP)',
         exportedVars   => 'Attributs à exporter',
-        generalParameters            => 'Paramètres généraux',
-        globalStorage                => 'Module Apache::Session',
-        globalStorageOptions         => 'Paramètres du module Apache::Session',
-        grantSessionRule             => "Conditions d'ouverture",
-        groups                       => 'Groupes',
-        headers                      => 'En-têtes HTTP',
-        hideOldPassword              => "Masquer l'ancien mot de passe",
-        httpOnly                     => 'Protection contre javascript',
-        https                        => 'HTTPS',
-        internalReference            => 'Référence interne ',
-        ipAddr                       => 'Adresse IP',
-        issuerParams                 => 'Modules fournisseur',
-        issuerDBSAML                 => 'SAML',
-        issuerDBSAMLActivation       => 'Activation',
-        issuerDBSAMLPath             => 'Chemin',
-        issuerDBSAMLRule             => 'Règle d\'utilisation',
-        issuerDBCAS                  => 'CAS',
-        issuerDBCASActivation        => 'Activation',
-        issuerDBCASPath              => 'Chemin',
-        issuerDBCASRule              => 'Règle d\'utilisation',
-        issuerDBCASOptions           => 'Options',
-        issuerDBOpenID               => 'OpenID',
-        issuerDBOpenIDActivation     => 'Activation',
-        issuerDBOpenIDPath           => 'Chemin',
-        issuerDBOpenIDRule           => 'Règle d\'utilisation',
-        issuerDBOpenIDOptions        => 'Options',
-        key                          => 'Clef de chiffrement',
-        ldap                         => 'LDAP',
-        ldapAuthnLevel               => 'Niveau d\'authentification',
-        ldapBase                     => 'Base de recherche des utilisateurs',
-        ldapChangePasswordAsUser     => 'Changement en tant qu\'utilisateur',
-        ldapConnection               => 'Connexion',
-        ldapFilters                  => 'Filtres',
-        LDAPFilter                   => 'Filtre par défaut',
-        ldapGroupAttributeName       => 'Attribut cible',
-        ldapGroupAttributeNameGroup  => 'Attribut source groupe',
-        ldapGroupAttributeNameSearch => 'Attributs recherchés',
-        ldapGroupAttributeNameUser   => 'Attribut source utilisateur',
-        ldapGroupBase                => 'Base de recherche',
-        ldapGroupObjectClass         => 'Classe d\'objet',
-        ldapGroupRecursive           => 'Récursif',
-        ldapGroups                   => 'Groupes',
-        ldapParams                   => 'Paramètres LDAP',
-        ldapPassword                 => 'Mot de passe',
-        ldapPasswordResetAttribute   => 'Attribut de réinitialisation',
+        failedLoginNumber      => 'Nombre d\'échecs de connexion mémorisés',
+        generalParameters      => 'Paramètres généraux',
+        globalStorage          => 'Module Apache::Session',
+        globalStorageOptions   => 'Paramètres du module Apache::Session',
+        grantSessionRules      => "Conditions d'ouverture",
+        groups                 => 'Groupes',
+        headers                => 'En-têtes HTTP',
+        hideOldPassword        => "Masquer l'ancien mot de passe",
+        httpOnly               => 'Protection contre javascript',
+        https                  => 'HTTPS',
+        internalReference      => 'Référence interne ',
+        ipAddr                 => 'Adresse IP',
+        issuerParams           => 'Modules fournisseur',
+        issuerDBSAML           => 'SAML',
+        issuerDBSAMLActivation => 'Activation',
+        issuerDBSAMLPath       => 'Chemin',
+        issuerDBSAMLRule       => 'Règle d\'utilisation',
+        issuerDBCAS            => 'CAS',
+        issuerDBCASActivation  => 'Activation',
+        issuerDBCASPath        => 'Chemin',
+        issuerDBCASRule        => 'Règle d\'utilisation',
+        issuerDBCASOptions     => 'Options',
+        issuerDBOpenID         => 'OpenID',
+        issuerDBOpenIDActivation        => 'Activation',
+        issuerDBOpenIDPath              => 'Chemin',
+        issuerDBOpenIDRule              => 'Règle d\'utilisation',
+        issuerDBOpenIDOptions           => 'Options',
+        jsRedirect                      => 'Message de redirection',
+        key                             => 'Clef de chiffrement',
+        ldap                            => 'LDAP',
+        ldapAuthnLevel                  => 'Niveau d\'authentification',
+        ldapBase                        => 'Base de recherche des utilisateurs',
+        ldapChangePasswordAsUser        => 'Changement en tant qu\'utilisateur',
+        ldapConnection                  => 'Connexion',
+        ldapFilters                     => 'Filtres',
+        LDAPFilter                      => 'Filtre par défaut',
+        ldapGroupAttributeName          => 'Attribut cible',
+        ldapGroupAttributeNameGroup     => 'Attribut source groupe',
+        ldapGroupAttributeNameSearch    => 'Attributs recherchés',
+        ldapGroupAttributeNameUser      => 'Attribut source utilisateur',
+        ldapGroupBase                   => 'Base de recherche',
+        ldapGroupObjectClass            => 'Classe d\'objet',
+        ldapGroupRecursive              => 'Récursif',
+        ldapGroups                      => 'Groupes',
+        ldapParams                      => 'Paramètres LDAP',
+        ldapPassword                    => 'Mot de passe',
+        ldapPasswordResetAttribute      => 'Attribut de réinitialisation',
         ldapPasswordResetAttributeValue => 'Valeur de réinitialisation',
         ldapPpolicyControl              => 'Contrôle password policy',
         ldapPort                        => 'Port',
@@ -619,24 +639,29 @@ sub fr {
         ldapTimeout     => 'Temps maximum d\'inactivité',
         ldapUsePasswordResetAttribute =>
           'Utiliser l\'attribut de réinitialisation',
-        ldapVersion        => 'Version',
-        logoutServices     => 'Transfert de la déconnexion',
-        logParams          => 'Journalisation',
-        macros             => 'Macros',
-        mailBody           => 'Contenu du message de succès',
-        mailCharset        => 'Charset',
-        mailConfirmBody    => 'Contenu du message de confirmation',
-        mailConfirmSubject => 'Sujet du message de confirmation',
-        mailContent        => 'Contenu du mail',
-        mailFrom           => 'Expéditeur du message',
-        mailHeaders        => 'En-têtes du mail',
-        mailLDAPFilter     => 'Filtre mail',
-        mailOther          => 'Autres',
-        mailReplyTo        => 'Adresse de réponse',
-        mailSessionKey     => 'Clé de session contenant l\'adresse email',
-        mailSubject        => 'Sujet du message de succès',
+        ldapVersion         => 'Version',
+        loginHistory        => 'Historique des connexions',
+        loginHistoryEnabled => 'Activation',
+        logoutServices      => 'Transfert de la déconnexion',
+        logParams           => 'Journalisation',
+        macros              => 'Macros',
+        mailBody            => 'Contenu du message de succès',
+        mailCharset         => 'Charset',
+        mailConfirmBody     => 'Contenu du message de confirmation',
+        mailConfirmSubject  => 'Sujet du message de confirmation',
+        mailContent         => 'Contenu du mail',
+        mailFrom            => 'Expéditeur du message',
+        mailHeaders         => 'En-têtes du mail',
+        mailLDAPFilter      => 'Filtre mail',
+        mailOnPasswordChange =>
+          "Envoi d'un mail quand le mot de passe est changé",
+        mailOther      => 'Autres',
+        mailReplyTo    => 'Adresse de réponse',
+        mailSessionKey => 'Clé de session contenant l\'adresse email',
+        mailSubject    => 'Sujet du message de succès',
         mailTimeout => "Durée de validité d'une demande de réinitialisation",
         mailUrl     => 'URL de la page',
+        maintenance => 'Mode maintenance',
         managerDn   => 'Compte de connexion LDAP',
         managerPassword     => 'Mot de passe LDAP',
         memberOfSSOGroups   => 'Membre des groupes SSO',
@@ -690,9 +715,11 @@ sub fr {
         portal                      => 'URL',
         portalAntiFrame             => 'Protection anti frame',
         portalAutocomplete          => 'Auto complétion',
+        portalCheckLogins           => 'Vérifier l\'historique',
         portalCustomization         => 'Personnalisation',
         portalDisplayAppslist       => 'Liste des applications',
         portalDisplayChangePassword => 'Changement de mot de passe',
+        portalDisplayLoginHistory   => 'Historique des connexions',
         portalDisplayLogout         => 'Déconnexion',
         portalDisplayResetPassword  => 'Réinitialisation de mot de passe',
         portalForceAuthn            => 'Authentication forcée',
@@ -700,15 +727,22 @@ sub fr {
         portalModules               => 'Modules',
         portalOpenLinkInNewWindow   => 'Nouvelle fenêtre',
         portalParams                => 'Portail',
+        portalRedirection           => 'Redirections du portail',
         portalRequireOldPassword    => 'Ancien mot de passe requis',
-        portalSkin                  => 'Thème visuel',
+        portalSkin                  => 'Thème visuel par défaut',
+        portalSkinRules             => "Règles d'affichage du thème visuel",
         portalUserAttr              => "Attribut de l'utilisateur",
         post                        => 'Rejeu de formulaires',
         proxyParams                 => 'Paramètres Proxy',
         purgeNotification => 'Supprimer définitivement la notification',
+        radiusAuthnLevel  => "Niveau d'authentification",
+        radiusParams      => 'Paramètres Radius',
+        radiusSecret      => 'Secret partagé',
+        radiusServer      => "Nom d'hôte du serveur",
         randomPasswordRegexp =>
           'Expression regulière pour la génération des mots de passe',
         redirection                 => 'Redirections du Handler',
+        reloadUrls                  => 'Mise à jour de la configuration',
         remoteCookieName            => 'Nom du cookie',
         remoteGlobalStorage         => 'Module des sessions',
         remoteGlobalStorageOptions  => 'Options du module des sessions',
@@ -726,6 +760,7 @@ sub fr {
         security                    => 'Sécurité',
         session                     => 'session',
         sessions                    => 'sessions',
+        sessionDataToRemember       => 'Données de session à conserver',
         sessionDeleted              => 'La session a été supprimée',
         sessionParams               => 'Sessions',
         sessionStartedAt            => 'Session démarrée le ',
@@ -735,6 +770,7 @@ sub fr {
         singleSession      => 'Une seule session par utilisateur',
         singleUserByIP     => 'Un seul utilisateur par IP',
         slaveAuthnLevel    => 'Niveau d\'authentification',
+        slaveMasterIP      => 'IP accréditées',
         slaveParams        => 'Paramètres Slave',
         slaveUserHeader    => "En-tête identifiant l'utilisateur",
         SMTPAuthPass       => 'Mot de passe SMTP',
@@ -746,45 +782,44 @@ sub fr {
         soapSessionService => 'Point d\'accès SOAP des sessions',
         specialHandlers    => 'Handlers spéciaux',
         SSLAuthnLevel      => 'Niveau d\'authentification',
-        SSLLDAPField       => 'Attribut LDAP pour le filtre',
         sslParams          => 'Paramètres SSL',
-        SSLRequire         => 'SSL Requis',
         SSLVar             => 'Champ extrait du certificat',
         startTime          => 'Date de création',
-        storePassword   => "Stocke le mot de passe de l'utilisateur en session",
-        sympaHandler    => 'Sympa',
-        sympaMailKey    => 'Clé de session pour le mail',
-        sympaSecret     => 'Secret partagé',
-        syntaxError     => 'Erreur de syntaxe',
-        syslog          => 'Facilité syslog',
-        timeout         => 'Durée de vie maximale des sessions',
-        timeoutActivity => 'Délai d\'expiration des sessions',
-        trustedDomains  => 'Domaines approuvés',
-        twitterAppName  => 'Nom de l\'application',
-        twitterAuthnLevel => 'Niveau d\'authentification',
-        twitterKey        => 'Clé de l\'API',
-        twitterParams     => 'Paramètres Twitter',
-        twitterSecret     => 'Secret de l\'API',
-        unknownError      => 'Erreur inconnue',
-        updateTime        => 'Date de mise à jour',
-        uploadDenied      => 'Téléchargement refusé',
-        user              => 'utilisateur',
-        users             => 'utilisateurs',
-        userDB            => "Module d'utilisateurs",
-        userControl       => "Contrôle du nom d'utilisateur",
-        userPivot         => 'Champ identifiant dans la table des utilisateurs',
+        storePassword => "Stocke le mot de passe de l'utilisateur en session",
+        successLoginNumber => 'Nombre de connexions mémorisées',
+        sympaHandler       => 'Sympa',
+        sympaMailKey       => 'Clé de session pour le mail',
+        sympaSecret        => 'Secret partagé',
+        syntaxError        => 'Erreur de syntaxe',
+        syslog             => 'Facilité syslog',
+        timeout            => 'Durée de vie maximale des sessions',
+        timeoutActivity    => 'Délai d\'expiration des sessions',
+        trustedDomains     => 'Domaines approuvés',
+        trustedProxies     => 'IP des proxys de confiance',
+        twitterAppName     => 'Nom de l\'application',
+        twitterAuthnLevel  => 'Niveau d\'authentification',
+        twitterKey         => 'Clé de l\'API',
+        twitterParams      => 'Paramètres Twitter',
+        twitterSecret      => 'Secret de l\'API',
+        unknownError       => 'Erreur inconnue',
+        updateTime         => 'Date de mise à jour',
+        uploadDenied       => 'Téléchargement refusé',
+        user               => 'utilisateur',
+        users              => 'utilisateurs',
+        userDB             => "Module d'utilisateurs",
+        userControl        => "Contrôle du nom d'utilisateur",
+        userPivot => 'Champ identifiant dans la table des utilisateurs',
         useRedirectOnError     => 'Redirection pour les erreurs',
         useRedirectOnForbidden => 'Redirection pour les accès interdits',
         useSafeJail            => 'Utiliser la cage Safe',
-        useXForwardedForIP     => "Utiliser X-Forwarded-For",
         variables              => "Variables",
         vhostHttps             => 'HTTPS',
+        vhostMaintenance       => 'Mode maintenance',
         vhostOptions           => 'Options',
         vhostPort              => 'Port',
         virtualHosts           => 'Hôtes virtuels',
         warning                => 'Attention',
         whatToTrace            => "REMOTE_USER",
-        xForwardedForAddr      => 'Adresse IP transférée',
         yubikeyAuthnLevel      => "Niveau d'authentification",
         yubikeyClientID        => "Identifiant client de l'API",
         yubikeyParams          => "Paramètres Yubikey",
