@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_SAML;    #inherits
 use Lemonldap::NG::Common::Conf::SAML::Metadata;
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.2.3';
 our @ISA     = qw(Lemonldap::NG::Portal::_SAML);
 
 ## @apmethod int authInit()
@@ -38,7 +38,7 @@ sub extractFormInfo {
 
     # 1. Get HTTP request informations to know
     # if we are receving SAML request or response
-    my $url            = $self->url();
+    my $url            = $self->url( -absolute => 1 );
     my $request_method = $self->request_method();
     my $content_type   = $self->content_type();
 
@@ -125,7 +125,18 @@ sub extractFormInfo {
               ->{samlIDPMetaDataOptionsCheckSSOMessageSignature};
 
             if ($checkSSOMessageSignature) {
-                unless ( $self->checkSignatureStatus($login) ) {
+
+                $self->forceSignatureVerification($login);
+
+                if ($artifact) {
+                    $result = $self->processArtResponseMsg( $login, $response );
+                }
+                else {
+                    $result =
+                      $self->processAuthnResponseMsg( $login, $response );
+                }
+
+                unless ($result) {
                     $self->lmLog( "Signature is not valid", 'error' );
                     return PE_SAML_SIGNATURE_ERROR;
                 }
@@ -162,8 +173,7 @@ sub extractFormInfo {
                     );
                     delete $self->{urldc};
                     $self->{mustRedirect} = 1;
-                    $self->{error} = $self->_subProcess(qw(autoRedirect));
-                    return $self->{error};
+                    return $self->_subProcess(qw(autoRedirect));
                 }
             }
             else {
@@ -190,7 +200,7 @@ sub extractFormInfo {
             if (
                 $checkConditions
                 and !$self->validateConditions(
-                    $assertion, $self->getMetaDataURL( "samlEntityID", 0 )
+                    $assertion, $self->getMetaDataURL( "samlEntityID", 0, 1 )
                 )
               )
             {
@@ -344,8 +354,7 @@ sub extractFormInfo {
 
             # Redirect user
             $self->{mustRedirect} = 1;
-            $self->{error}        = $self->_subProcess(qw(autoRedirect));
-            return $self->{error};
+            return $self->_subProcess(qw(autoRedirect));
         }
 
     }
@@ -406,7 +415,12 @@ sub extractFormInfo {
               ->{samlIDPMetaDataOptionsCheckSLOMessageSignature};
 
             if ($checkSLOMessageSignature) {
-                unless ( $self->checkSignatureStatus($logout) ) {
+
+                $self->forceSignatureVerification($logout);
+
+                $result = $self->processLogoutResponseMsg( $logout, $response );
+
+                unless ($result) {
                     $self->lmLog( "Signature is not valid", 'error' );
                     return PE_SAML_SIGNATURE_ERROR;
                 }
@@ -437,7 +451,7 @@ sub extractFormInfo {
                     'debug' );
             }
 
-            $self->_subProcess(qw(autoRedirect))
+            return $self->_subProcess(qw(autoRedirect))
               if (  $self->{urldc}
                 and $self->{portal} !~ /\Q$self->{urldc}\E\/?/ );
 
@@ -661,12 +675,7 @@ sub extractFormInfo {
 
                 $self->{urldc} = $slo_url;
 
-                $self->_subProcess(qw(autoRedirect));
-
-                # If we are here, there was a problem with GET request
-                $self->lmLog( "Logout response was not sent trough GET",
-                    'error' );
-                return PE_SAML_SLO_ERROR;
+                return $self->_subProcess(qw(autoRedirect));
             }
 
             # HTTP-POST
@@ -683,12 +692,7 @@ sub extractFormInfo {
                 $self->{postFields}->{'RelayState'} = $relaystate
                   if ($relaystate);
 
-                $self->_subProcess(qw(autoPost));
-
-                # If we are here, there was a problem with POST response
-                $self->lmLog( "Logout response was not sent trough POST",
-                    'error' );
-                return PE_SAML_SLO_ERROR;
+                return $self->_subProcess(qw(autoPost));
             }
 
             # HTTP-SOAP
@@ -716,8 +720,7 @@ sub extractFormInfo {
 
             # Redirect user
             $self->{mustRedirect} = 1;
-            $self->{error}        = $self->_subProcess(qw(autoRedirect));
-            return $self->{error};
+            return $self->_subProcess(qw(autoRedirect));
         }
     }
 
@@ -773,14 +776,6 @@ sub extractFormInfo {
     # Get confirmation flag
     my $confirm_flag = $self->param("confirm");
 
-    # If confirmation is -1 from IDP list,
-    # return error to get next authentication method
-    # with AuthMulti
-    if ( $confirm_flag == -1 and $self->param("idplist") ) {
-        $self->lmLog( "SAML authentication refused by user", 'error' );
-        return PE_ERROR;
-    }
-
     # If confirmation is -1 from resolved IDP screen,
     # or IDP was not resolve, let the user choose its IDP
     if ( $confirm_flag == -1 or !$idp ) {
@@ -791,40 +786,15 @@ sub extractFormInfo {
         return $urlcheck unless ( $urlcheck == PE_OK );
 
         # IDP list
-        my $html = "<h3>"
-          . &Lemonldap::NG::Portal::_i18n::msg( PM_SAML_IDPSELECT,
-            $ENV{HTTP_ACCEPT_LANGUAGE} )
-          . "</h3>\n<table>\n";
-
+        my @list = ();
         foreach ( keys %{ $self->{_idpList} } ) {
-            $html .=
-                '<tr><td><input type="radio" name="idp" value="' 
-              . $_
-              . '" /></td><td>'
-              . $self->{_idpList}->{$_}->{name}
-              . '</td></tr>';
+            push @list,
+              {
+                val  => $_,
+                name => $self->{_idpList}->{$_}->{name}
+              };
         }
-
-        $html .=
-'<tr><td><input type="checkbox" name="cookie_type" value="1"></td><td>'
-          . &Lemonldap::NG::Portal::_i18n::msg( PM_REMEMBERCHOICE,
-            $ENV{HTTP_ACCEPT_LANGUAGE} )
-          . "</td></tr></table>\n"
-
-          # URL
-          . '<input type="hidden" name="url" value="'
-          . $self->param("url") . '" />'
-
-          # IDP list flag
-          . '<input type="hidden" name="idplist" value="1" />'
-
-          # Script to autoselect first choice
-          . '<script>$("[type=radio]:first").attr("checked","checked");</script>';
-
-        $self->info($html);
-
-        # Timer not active on IDP list
-        $self->{activeTimer} = 0;
+        $self->{list} = \@list;
 
         # Delete existing IDP resolution cookie
         push @{ $self->{cookie} },
@@ -837,6 +807,7 @@ sub extractFormInfo {
             -expires => '-1d',
           );
 
+        $self->{login} = 1;
         return PE_CONFIRM;
     }
 
@@ -850,8 +821,7 @@ sub extractFormInfo {
 
         # Choosen IDP
         my $html = '<h3>'
-          . &Lemonldap::NG::Portal::_i18n::msg( PM_SAML_IDPCHOOSEN,
-            $ENV{HTTP_ACCEPT_LANGUAGE} )
+          . $self->msg(PM_SAML_IDPCHOOSEN)
           . "</h3>\n" . "<h4>"
           . $self->{_idpList}->{$idp}->{name}
           . "</h4>\n"
@@ -864,6 +834,7 @@ sub extractFormInfo {
 
         $self->info($html);
 
+        $self->{login} = 1;
         return PE_CONFIRM;
     }
 
@@ -1016,11 +987,7 @@ sub extractFormInfo {
 
         $self->{urldc} = $sso_url;
 
-        $self->_subProcess(qw(autoRedirect));
-
-        # If we are here, there was a problem with GET request
-        $self->lmLog( "SSO request was not sent trough GET", 'error' );
-        return PE_SAML_SSO_ERROR;
+        return $self->_subProcess(qw(autoRedirect));
     }
 
     # HTTP-POST
@@ -1045,11 +1012,7 @@ sub extractFormInfo {
         $self->{postFields}->{'RelayState'} = $login->msg_relayState
           if ( $login->msg_relayState );
 
-        $self->_subProcess(qw(autoPost));
-
-        # If we are here, there was a problem with POST request
-        $self->lmLog( "SSO request was not sent trough POST", 'error' );
-        return PE_SAML_SSO_ERROR;
+        return $self->_subProcess(qw(autoPost));
     }
 
     # No SOAP transport for SSO request
@@ -1221,7 +1184,6 @@ sub getIDP {
             and $self->{samlCommonDomainCookieActivation}
             and $self->{samlCommonDomainCookieReader} )
         {
-
             $self->lmLog(
                 "Will try to use Common Domain Cookie for IDP resolution",
                 'debug' );
@@ -1241,8 +1203,7 @@ sub getIDP {
 
             $self->{urldc} = $cdc_reader_url;
 
-            return $self->_sub('autoRedirect');
-
+            return $self->_subProcess('autoRedirect');
         }
 
         $self->lmLog( 'No IDP found', 'debug' ) unless ($idp);
@@ -1358,6 +1319,10 @@ sub authLogout {
         $self->{postUrl} = $slo_url;
         $self->{postFields} = { 'SAMLRequest' => $slo_body };
 
+        # RelayState
+        $self->{postFields}->{'RelayState'} = $logout->msg_relayState
+          if ( $logout->msg_relayState );
+
         # Post done in Portal/Simple.pm
         return PE_OK;
     }
@@ -1410,7 +1375,7 @@ sub authLogout {
 sub authForce {
     my $self = shift;
 
-    my $url = $self->url();
+    my $url = $self->url( -absolute => 1 );
 
     my $saml_acs_art_url = $self->getMetaDataURL(
         "samlSPSSODescriptorAssertionConsumerServiceHTTPArtifact");
@@ -1485,6 +1450,12 @@ sub authFinish {
     return PE_OK;
 }
 
+## @method string getDisplayType
+# @return display type
+sub getDisplayType {
+    return "logo";
+}
+
 1;
 
 __END__
@@ -1509,14 +1480,57 @@ L<Lemonldap::NG::Portal>, L<Lemonldap::NG::Portal::UserDBSAML>, L<Lemonldap::NG:
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>, Clement Oudot, E<lt>coudot@linagora.comE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
+
+=item Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
+
+=back
+
+=head1 BUG REPORT
+
+Use OW2 system to report bug or ask for features:
+L<http://jira.ow2.org>
+
+=head1 DOWNLOAD
+
+Lemonldap::NG is available at
+L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, 2010 by Xavier Guimard
+=over
+
+=item Copyright (C) 2009, 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2012 by Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
+
+=item Copyright (C) 2012 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Copyright (C) 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Copyright (C) 2010 by Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
