@@ -23,7 +23,7 @@ sub menuInit {
     $self->{apps}->{imgpath} ||= '/apps/';
 
     # Modules to display
-    $self->{menuModules} ||= "Appslist ChangePassword Logout";
+    $self->{menuModules} ||= "Appslist ChangePassword LoginHistory Logout";
     $self->{menuDisplayModules} = $self->displayModules();
 
     # Extract password from POST data
@@ -34,10 +34,12 @@ sub menuInit {
     $self->{user}            = $self->{sessionInfo}->{_user};
 
     # Try to change password
-    $self->{menuError} = $self->_subProcess(qw(passwordDBInit modifyPassword))
+    $self->{menuError} =
+      $self->_subProcess(qw(passwordDBInit modifyPassword sendPasswordMail))
       unless $self->{ignorePasswordChange};
 
     # Default menu error code
+    $self->{menuError} = PE_PASSWORD_OK if ( $self->{passwordWasChanged} );
     $self->{menuError} ||= $self->{error};
 
     # Tab to display
@@ -64,6 +66,7 @@ sub menuInit {
                     33,    #PE_PP_EXP_WARNING
                     34,    #PE_PASSWORD_MISMATCH
                     39,    #PE_BADOLDPASSWORD
+                    74,    #PE_MUST_SUPPLY_OLD_PASSWORD
                 )
             )
         )
@@ -100,6 +103,16 @@ sub displayModules {
             my $moduleHash = { $module => 1 };
             $moduleHash->{'APPSLIST_LOOP'} = $self->appslist()
               if ( $module eq 'Appslist' );
+            if ( $module eq 'LoginHistory' ) {
+                $moduleHash->{'SUCCESS_LOGIN'} =
+                  $self->mkSessionArray(
+                    $self->{sessionInfo}->{loginHistory}->{successLogin},
+                    "", 0, 0 );
+                $moduleHash->{'FAILED_LOGIN'} =
+                  $self->mkSessionArray(
+                    $self->{sessionInfo}->{loginHistory}->{failedLogin},
+                    "", 0, 1 );
+            }
             push @$displayModules, $moduleHash;
         }
     }
@@ -563,7 +576,15 @@ L<Lemonldap::NG::Portal>, L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
-Clement OUDOT E<lt>clement@oodo.netE<gt> E<lt>coudot@linagora.comE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=back
 
 =head1 BUG REPORT
 
@@ -577,12 +598,28 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005, 2007, 2010 by Clement OUDOT E<lt>clement@oodo.netE<gt>
-E<lt>coudot@linagora.comE<gt>
+=over
+
+=item Copyright (C) 2008, 2009, 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2012 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
 
