@@ -63,7 +63,7 @@ use Digest::MD5;
 #inherits Apache::Session
 #link Lemonldap::NG::Common::Apache::Session::SOAP protected globalStorage
 
-our $VERSION = '1.2.2';
+our $VERSION = '1.2.5';
 
 use base qw(Lemonldap::NG::Common::CGI Exporter);
 our @ISA;
@@ -456,7 +456,7 @@ sub new {
     $self->{trustedDomains} = "*"
       if ( $self->{trustedDomains} =~ /(^|\s)\*(\s|$)/ );
     if ( $self->{trustedDomains} and $self->{trustedDomains} ne "*" ) {
-        $self->{trustedDomains} =~ s#(^|\s+)\.#[^/]+.#g;
+        $self->{trustedDomains} =~ s#(^|\s+)\.#${1}[^/]+.#g;
         $self->{trustedDomains} =
           '(' . join( '|', split( /\s+/, $self->{trustedDomains} ) ) . ')';
         $self->{trustedDomains} =~ s/\./\\./g;
@@ -470,7 +470,7 @@ sub new {
 # @param module module name
 # @return boolean
 sub loadModule {
-    my ($self, $module) = splice @_;
+    my ( $self, $module ) = splice @_;
 
     return 1 unless $module;
 
@@ -921,7 +921,8 @@ sub getApacheSession {
 
         # Session not available (expired ?)
         if ($id) {
-            $self->lmLog( "Session $id isn't yet available ($ENV{REMOTE_ADDR})",
+            $self->lmLog(
+                "Session $id can't be retrieved (" . $self->ipAddr . ")",
                 'info' )
               unless $noInfo;
         }
@@ -1162,7 +1163,7 @@ sub _subProcess {
 sub updateStatus {
     my $self = shift;
     print $Lemonldap::NG::Handler::Simple::statusPipe (
-        $self->{user} ? $self->{user} : $ENV{REMOTE_ADDR} )
+        $self->{user} ? $self->{user} : $self->ipAddr )
       . " => $ENV{SERVER_NAME}$ENV{SCRIPT_NAME} "
       . $self->{error} . "\n"
       if ($Lemonldap::NG::Handler::Simple::statusPipe);
@@ -1253,6 +1254,9 @@ sub safe {
         # Refresh the portal object inside it
         $safe->{p} = $self;
 
+        # Refresh environment variables
+        $safe->share_from( 'main', ['%ENV'] );
+
         return $safe;
     }
 
@@ -1426,6 +1430,61 @@ sub stamp {
     return $self->{cipher} ? $self->{cipher}->encrypt( time() ) : 1;
 }
 
+## @method string convertSec(int sec)
+# Convert seconds to hours, minutes, seconds
+#@param $sec number of seconds
+# @return a formated time
+sub convertSec {
+    my ( $self, $sec ) = splice @_;
+    my ( $day, $hrs, $min ) = ( 0, 0, 0 );
+
+    # Calculate the minutes
+    if ( $sec > 60 ) {
+        $min = $sec / 60, $sec %= 60;
+        $min = int($min);
+    }
+
+    # Calculate the hours
+    if ( $min > 60 ) {
+        $hrs = $min / 60, $min %= 60;
+        $hrs = int($hrs);
+    }
+
+    # Calculate the days
+    if ( $hrs > 24 ) {
+        $day = $hrs / 24, $hrs %= 24;
+        $day = int($day);
+    }
+
+    # Return the date
+    return ( $day, $hrs, $min, $sec );
+}
+
+## @method string getSkin()
+# Return skin name
+# @return skin name
+sub getSkin {
+    my ($self) = splice @_;
+
+    my $skin = $self->{portalSkin};
+
+    # Fill sessionInfo to eval rule if empty (unauthenticated user)
+    $self->{sessionInfo}->{_url}   ||= $self->{urldc};
+    $self->{sessionInfo}->{ipAddr} ||= $self->ipAddr;
+
+    # Load specific skin from skinRules
+    if ( $self->{portalSkinRules} ) {
+        foreach my $skinRule ( sort keys %{ $self->{portalSkinRules} } ) {
+            if ( $self->safe->reval($skinRule) ) {
+                $skin = $self->{portalSkinRules}->{$skinRule};
+                $self->lmLog( "Skin $skin selected from skin rule", 'debug' );
+            }
+        }
+    }
+
+    return $skin;
+}
+
 ###############################################################
 # MAIN subroutine: call all steps until one returns something #
 #                  different than PE_OK                       #
@@ -1664,21 +1723,35 @@ sub controlExistingSession {
                 }
 
                 # Call logout for the module used to authenticate
+                $self->lmLog(
+                    "Process logout for authentication module " . $h->{_auth},
+                    'debug' );
+
                 if ( $h->{'_auth'} ne $self->get_module('auth') ) {
-                    $self->loadModule(
-                        "Lemonldap::NG::Portal::Auth" . $h->{_auth} );
-                    eval {
-                        $self->{error} =
-                          $self->_sub( "Lemonldap::NG::Portal::Auth"
-                              . $h->{_auth}
-                              . "::authLogout" );
-                    };
+                    my $module_name =
+                      'Lemonldap::NG::Portal::Auth' . $h->{_auth};
+
+                    unless ( $self->loadModule($module_name) ) {
+                        $self->lmLog( "Unable to load $module_name", 'error' );
+                    }
+                    else {
+                        eval {
+                            $self->{error} = $self->_subProcess(
+                                $module_name . "::authInit",
+                                $module_name . "::authLogout"
+                            );
+                        };
+                    }
                 }
                 else {
-                    eval { $self->{error} = $self->_sub('authLogout'); };
+                    eval {
+                        $self->{error} =
+                          $self->_subProcess( 'authInit', 'authLogout' );
+                    };
                 }
                 if ($@) {
-                    $self->lmLog( "Error when calling authLogout: $@",
+                    $self->lmLog(
+                        "Error when calling authentication logout: $@",
                         'debug' );
                 }
                 return $self->{error} if $self->{error} > 0;
@@ -1746,6 +1819,15 @@ sub controlExistingSession {
                   . '{"auth":true}';
                 $self->quit();
             }
+
+            # Special ajax request "storeAppsListOrder"
+            if ( $self->param('storeAppsListOrder') ) {
+                my $order = $self->param('storeAppsListOrder');
+                $self->lmLog( "Get new apps list order: $order", 'debug' );
+                $self->updatePersistentSession( { appsListOrder => $order } );
+                $self->quit();
+            }
+
             $self->{id} = $id;
 
             # A session has been found => call existingSession
@@ -1917,7 +1999,7 @@ sub modifyPassword {
 }
 
 ##@apmethod int setSessionInfo()
-# Set ipAddr, xForwardedForAddr, startTime, updateTime, _utime and _userDB
+# Set ipAddr, startTime, updateTime, _utime and _userDB
 # Call setSessionInfo() in UserDB* module
 #@return Lemonldap::NG::Portal constant
 sub setSessionInfo {
@@ -1927,15 +2009,7 @@ sub setSessionInfo {
     $self->{sessionInfo}->{_userDB} = $self->get_module("user");
 
     # Store IP address from remote address or X-FORWARDED-FOR header
-    my $xheader = $ENV{HTTP_X_FORWARDED_FOR};
-    $xheader =~ s/(.*?)(\,)+.*/$1/ if $xheader;
-
-    if ( $xheader and $self->{useXForwardedForIP} ) {
-        $self->{sessionInfo}->{ipAddr} = $xheader;
-    }
-    else {
-        $self->{sessionInfo}->{ipAddr} = $ENV{REMOTE_ADDR};
-    }
+    $self->{sessionInfo}->{ipAddr} = $self->ipAddr;
 
     # Date and time
     if ( $self->{updateSession} ) {
@@ -1974,8 +2048,9 @@ sub setSessionInfo {
 #@return Lemonldap::NG::Portal constant
 sub setMacros {
     my $self = shift;
-    while ( my ( $n, $e ) = each( %{ $self->{macros} } ) ) {
-        $self->{sessionInfo}->{$n} = $self->safe->reval($e);
+    foreach ( sort keys %{ $self->{macros} } ) {
+        $self->{sessionInfo}->{$_} =
+          $self->safe->reval( $self->{macros}->{$_} );
     }
     PE_OK;
 }
@@ -1985,27 +2060,17 @@ sub setMacros {
 # * store all groups name that the user match in $self->{sessionInfo}->{groups}
 #@return Lemonldap::NG::Portal constant
 sub setLocalGroups {
-    my $self   = shift;
-    my $groups = "";
-    while ( my ( $group, $expr ) = each %{ $self->{groups} } ) {
-        $groups .= $group . $self->{multiValuesSeparator}
-          if ( $self->safe->reval($expr) );
+    my $self = shift;
+    foreach ( sort keys %{ $self->{groups} } ) {
+        $self->{sessionInfo}->{groups} .= $self->{multiValuesSeparator} . $_
+          if ( $self->safe->reval( $self->{groups}->{$_} ) );
     }
 
-    # Join local and UserDB groups
-    if ($groups) {
-        $self->{sessionInfo}->{groups} .=
-          $self->{multiValuesSeparator} . $groups;
-    }
-
-    # Clear values separator at begin or end
+    # Clear values separator at the beginning
     if ( $self->{sessionInfo}->{groups} ) {
         $self->{sessionInfo}->{groups} =~
           s/^\Q$self->{multiValuesSeparator}\E//;
-        $self->{sessionInfo}->{groups} =~
-          s/\Q$self->{multiValuesSeparator}\E$//;
     }
-
     PE_OK;
 }
 
@@ -2146,8 +2211,8 @@ sub removeOther {
     }
     if ( $self->{singleUserByIP} ) {
         my $sessions =
-          $self->{globalStorage}->searchOn( $self->{globalStorageOptions},
-            'ipAddr', $ENV{REMOTE_ADDR} );
+          $self->{globalStorage}
+          ->searchOn( $self->{globalStorageOptions}, 'ipAddr', $self->ipAddr );
         foreach my $id ( keys %$sessions ) {
             next if ( $current and $current eq $id );
             my $h = $self->getApacheSession( $id, 1 ) or next;
@@ -2929,7 +2994,19 @@ L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
+
+=item Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
+
+=back
 
 =head1 BUG REPORT
 
@@ -2943,11 +3020,31 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005, 2009, 2010 by Xavier Guimard E<lt>x.guimard@free.frE<gt> and
-Clement Oudot, E<lt>coudot@linagora.comE<gt>
+=over
+
+=item Copyright (C) 2006, 2007, 2008, 2009, 2010, 2012 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2012 by Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
+
+=item Copyright (C) 2012, 2012, 2013 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Copyright (C) 2006, 2008, 2009, 2010, 2011, 2012, 2012, 2013 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Copyright (C) 2010, 2011 by Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
