@@ -10,16 +10,17 @@ use Lemonldap::NG::Common::Conf::SAML::Metadata;
 use XML::Simple;
 use MIME::Base64;
 use String::Random;
-use LWP::UserAgent;    # SOAP call
-use HTTP::Request;     # SOAP call
-use POSIX;             # Convert SAML2 date into timestamp
-use Time::Local;       # Convert SAML2 date into timestamp
-use Encode;            # Encode attribute values
+use LWP::UserAgent;        # SOAP call
+use HTTP::Request;         # SOAP call
+use POSIX qw(strftime);    # Convert SAML2 date into timestamp
+use Time::Local;           # Convert SAML2 date into timestamp
+use Encode;                # Encode attribute values
+use URI;                   # Get metadata URL path
 
 # Special comments for doxygen
 #inherits Lemonldap::NG::Common::Conf::SAML::Metadata protected service_metadata
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.2.3';
 our $samlCache;
 our $initGlibDone;
 
@@ -71,6 +72,20 @@ BEGIN {
 # @return boolean result
 sub loadLasso {
     my $self = shift;
+
+    # Reload SAML cache if configuration number has changed
+    unless ( $samlCache->{cfgNum} == $self->{cfgNum} ) {
+        $self->lmLog( "Reset SAML configuration cache", 'debug' );
+        delete $samlCache->{_lassoServerDump};
+        delete $samlCache->{_spList};
+        delete $samlCache->{_idpList};
+
+        $samlCache->{cfgNum} = $self->{cfgNum};
+    }
+
+    $self->lmLog( "SAML cache configuration: " . $samlCache->{cfgNum},
+        'debug' );
+
     return 1 if ($initGlibDone);
 
     # Catch GLib Lasso messages (require Glib)
@@ -86,7 +101,7 @@ sub loadLasso {
     }
 
     unless (LASSO) {
-        $self->lmLog( "Module Lasso not loaded (see bellow)", 'error' );
+        $self->lmLog( "Module Lasso not loaded (see below)", 'error' );
         return 0;
     }
 
@@ -96,6 +111,7 @@ sub loadLasso {
     }
 
     $initGlibDone = 1;
+
     return 1;
 }
 
@@ -154,7 +170,8 @@ sub loadService {
     # Create Lasso server with service metadata
     my $server = $self->createServer(
         $service_metadata->serviceToXML(
-            $ENV{DOCUMENT_ROOT} . "/skins/common/saml2-metadata.tpl", $self
+            $self->getApacheHtdocsPath() . "/skins/common/saml2-metadata.tpl",
+            $self
         ),
         $privateKeySig,
         $privateKeySigPwd,
@@ -776,7 +793,7 @@ sub createAuthnRequest {
 
     # Set RelayState
     my $infos;
-    foreach (qw /urldc/) {
+    foreach (qw /urldc checkLogins/) {
         $infos->{$_} = $self->{$_} if $self->{$_};
     }
     my $relaystate = $self->storeRelayState($infos);
@@ -1343,7 +1360,7 @@ sub createLogoutRequest {
 
     # Set RelayState
     my $infos;
-    foreach (qw /urldc/) {
+    foreach (qw /urldc checkLogins/) {
         $infos->{$_} = $self->{$_} if $self->{$_};
     }
     my $relaystate = $self->storeRelayState($infos);
@@ -1456,10 +1473,12 @@ sub setIdentityFromDump {
 # Replace #PORTAL# macro
 # @param key Metadata configuration key
 # @param index field index containing URL
+# @param full Return full URL instead of path
 # @return url
 sub getMetaDataURL {
-    my ( $self, $key, $index ) = splice @_;
+    my ( $self, $key, $index, $full ) = splice @_;
     $index = 3 unless defined $index;
+    $full  = 0 unless defined $full;
 
     return unless defined $self->{$key};
 
@@ -1472,8 +1491,12 @@ sub getMetaDataURL {
     # Replace #PORTAL# macro
     $url =~ s/#PORTAL#/$portal/g;
 
-    # Return URL
-    return $url;
+    # Return Full URL
+    return $url if $full;
+
+    # Return only path
+    my $uri = URI->new($url);
+    return $uri->path();
 }
 
 ## @method boolean processLogoutResponseMsg(Lasso::Logout logout, string response)
@@ -1553,9 +1576,9 @@ sub storeReplayProtection {
 
     return 0 unless $samlSessionInfo;
 
-    $samlSessionInfo->{type}   = 'assertion';    # Session type
-    $samlSessionInfo->{_utime} = time();         # Creation time
-    $samlSessionInfo->{ID}     = $samlID;
+    $samlSessionInfo->{type}       = 'assertion';    # Session type
+    $samlSessionInfo->{_utime}     = time();         # Creation time
+    $samlSessionInfo->{_assert_id} = $samlID;
 
     if ( defined $samlData && $samlData ) {
         $samlSessionInfo->{data} = $samlData;
@@ -1586,7 +1609,7 @@ sub replayProtection {
 
     my $sessions =
       $self->{samlStorage}
-      ->searchOn( $self->{samlStorageOptions}, "ID", $samlID );
+      ->searchOn( $self->{samlStorageOptions}, "_assert_id", $samlID );
 
     if ( my @keys = keys %$sessions ) {
 
@@ -1685,7 +1708,7 @@ sub storeArtifact {
 
     $samlSessionInfo->{type}     = 'artifact';                   # Session type
     $samlSessionInfo->{_utime}   = time();                       # Creation time
-    $samlSessionInfo->{ID}       = $id;
+    $samlSessionInfo->{_art_id}  = $id;
     $samlSessionInfo->{message}  = $message;
     $samlSessionInfo->{_saml_id} = $session_id if $session_id;
 
@@ -1712,7 +1735,8 @@ sub loadArtifact {
     }
 
     my $sessions =
-      $self->{samlStorage}->searchOn( $self->{samlStorageOptions}, "ID", $id );
+      $self->{samlStorage}
+      ->searchOn( $self->{samlStorageOptions}, "_art_id", $id );
 
     if ( my @keys = keys %$sessions ) {
 
@@ -2218,6 +2242,21 @@ sub disableSignatureVerification {
     return $self->checkLassoError($@);
 }
 
+## @method boolean forceSignatureVerification(Lasso::Profile profile)
+# Modify Lasso signature hint to force signature verification
+# @param profile Lasso profile object
+# @return result
+sub forceSignatureVerification {
+    my ( $self, $profile ) = splice @_;
+
+    eval {
+        Lasso::Profile::set_signature_verify_hint( $profile,
+            Lasso::Constants::PROFILE_SIGNATURE_VERIFY_HINT_FORCE );
+    };
+
+    return $self->checkLassoError($@);
+}
+
 ## @method string getAuthnContext(string context)
 # Convert configuration string into SAML2 AuthnContextClassRef string
 # @param context configuration string
@@ -2249,7 +2288,7 @@ sub timestamp2samldate {
     my ( $self, $timestamp ) = splice @_;
 
     my @t = gmtime($timestamp);
-    my $samldate = POSIX::strftime( "%Y-%m-%dT%TZ", @t );
+    my $samldate = strftime( "%Y-%m-%dT%TZ", @t );
 
     $self->lmLog( "Convert timestamp $timestamp in SAML2 date: $samldate",
         'debug' );
@@ -2300,13 +2339,7 @@ sub sendLogoutResponseToServiceProvider {
 
         $self->lmLog( "Redirect user to $slo_url", 'debug' );
 
-        $self->_subProcess(qw(autoRedirect));
-
-        # If we are here, there was a problem with HTTP-REDIRECT response
-        $self->lmLog( "Logout response was not sent trough GET", 'error' );
-
-        return 0;
-
+        return $self->_subProcess(qw(autoRedirect));
     }
 
     # HTTP-POST
@@ -2324,13 +2357,7 @@ sub sendLogoutResponseToServiceProvider {
         $self->{postFields}->{'RelayState'} = $relaystate
           if ($relaystate);
 
-        $self->_subProcess(qw(autoPost));
-
-        # If we are here, there was a problem with POST response
-        $self->lmLog( "Logout response was not sent trough POST", 'error' );
-
-        return 0;
-
+        return $self->_subProcess(qw(autoPost));
     }
 
     # HTTP-SOAP
@@ -2449,6 +2476,11 @@ sub sendLogoutRequestToProvider {
 
     }
 
+    unless ( $logout->request() ) {
+        $self->lmLog( "Unable to create SAML request", 'error' );
+        return ( 0, $method, undef );
+    }
+
     # Keep message ID in memory to prevent replay
     my $samlID = $logout->request()->ID;
     unless ( $self->storeReplayProtection($samlID) ) {
@@ -2626,10 +2658,7 @@ sub sendLogoutRequestToProviders {
 
     # Header of the block which will be displayed to the user, if needed.
     $info .= '<h3>'
-      . &Lemonldap::NG::Portal::_i18n::msg
-      ( Lemonldap::NG::Portal::Simple::PM_SAML_SPLOGOUT,
-        $ENV{HTTP_ACCEPT_LANGUAGE} )
-      . '</h3>'
+      . $self->msg(Lemonldap::NG::Portal::Simple::PM_SAML_SPLOGOUT) . '</h3>'
       . '<table class="sloState">';
 
     # Foreach SP found in session, get it from configuration, and send the
@@ -2660,7 +2689,6 @@ sub sendLogoutRequestToProviders {
     $self->info($info) if $providersCount;
 
     return $providersCount;
-
 }
 
 ## @method boolean checkSignatureStatus(Lasso::Profile profile)
@@ -2736,15 +2764,19 @@ sub checkDestination {
 
     $self->lmLog( "Destination $destination found in SAML message", 'debug' );
 
+    # Retrieve full URL
+    my $portal = $self->{portal};
+    $portal =~ s#^(https?://[^/]+)/.*#$1#;    # remove path of portal URL
+    $url = $portal . $url;
+
     # Compare Destination and URL
-    if ( $destination =~ /^$url$/ ) {
+    if ( $destination eq $url ) {
         $self->lmLog( "Destination match URL $url", 'debug' );
         return 1;
     }
-    else {
-        $self->lmLog( "Destination does not match URL $url", 'error' );
-        return 0;
-    }
+
+    $self->lmLog( "Destination does not match URL $url", 'error' );
+    return 0;
 }
 
 ## @method hashref getSamlSession(string id)
@@ -2935,14 +2967,7 @@ sub sendSLOErrorResponse {
     }
 
     # Send unvalidated SLO response
-    unless ( $self->sendLogoutResponseToServiceProvider( $logout, $method ) ) {
-        $self->lmLog( "Could not send SLO error response", 'error' );
-        $self->quit();
-    }
-
-    $self->lmLog( "SLO response error sent", 'debug' );
-
-    $self->quit();
+    return $self->sendLogoutResponseToServiceProvider( $logout, $method );
 }
 
 1;
@@ -3223,6 +3248,10 @@ Modify Lasso signature hint to force signature
 
 Modify Lasso signature hint to disable signature verification
 
+=head2 forceSignatureVerification
+
+Modify Lasso signature hint to force signature verification
+
 =head2 getAuthnContext
 
 Convert configuration string into SAML2 AuthnContextClassRef string
@@ -3300,15 +3329,57 @@ L<Lemonldap::NG::Portal::AuthSAML>, L<Lemonldap::NG::Portal::UserDBSAML>
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>,
-Clement Oudot, E<lt>coudot@linagora.comE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
+
+=item Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
+
+=back
+
+=head1 BUG REPORT
+
+Use OW2 system to report bug or ask for features:
+L<http://jira.ow2.org>
+
+=head1 DOWNLOAD
+
+Lemonldap::NG is available at
+L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, 2010 by Xavier Guimard, Clement Oudot
+=over
+
+=item Copyright (C) 2009, 2010, 2011, 2012 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2012 by Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
+
+=item Copyright (C) 2012 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Copyright (C) 2010, 2011, 2012, 2013 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Copyright (C) 2010, 2011 by Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
