@@ -6,7 +6,7 @@
 # Use Dokuwiki offline plugin
 #
 # This script is part of LemonLDAP::NG project
-# Released under GPL licence
+# Released under GPL license
 #====================================================================
 
 use strict;
@@ -61,4 +61,7 @@ my @links = (
 
 splice @index, 22, 1, @links;
 
+# Remove external logos
+system('rm -rf media/applications/ media/logos/');
+
 exit 0;
